Set

Trait Set 

pub trait Set {
    type Config;

    // Required methods
    fn init(config: Self::Config) -> Self;
    fn tables(&self) -> Vec<&dyn DynTable>;
}
A named dataset made up of one or more Tables.

Required Associated Types

type Config

Configuration necessary for construct this dataset.

Required Methods

fn init(config: Self::Config) -> Self

Construct an instance of this dataset with the given configuration.

fn tables(&self) -> Vec<&dyn DynTable>

The tables making up this dataset.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors